@@ -11,6 +11,9 @@ import _sm3 as sm3core
 
 class sm3(object):
 
+    digest_size = 32
+    block_size = 64
+
     def __init__(self, data=None):
         self.ctx = sm3core.pysm3_init()
         if data:
